//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[allYaku](all-yaku.md)

# allYaku

[common]\
val [allYaku](all-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../-yaku/index.md)&gt;

所有役种
